@@ -16,10 +16,11 @@
 import hashlib
 import json
 import os
+import types
 import warnings
 from functools import wraps
 from inspect import getmembers, isfunction
-from typing import Optional
+from typing import Optional, Any, Dict
 from unittest.mock import Mock, patch
 
 from iconservice import InterfaceScore
@@ -28,17 +29,16 @@ from iconservice.base.exception import InvalidPayableException, InvalidInterface
 from iconservice.database.db import IconScoreDatabase
 from iconservice.icon_constant import IconScoreFuncType, IconScoreContextType
 from iconservice.iconscore.icon_score_base2 import _create_address_with_key, _recover_key
-from iconservice.iconscore.icon_score_constant import CONST_BIT_FLAG, ConstBitFlag, FORMAT_IS_NOT_DERIVED_OF_OBJECT
-from iconservice.iconscore.icon_score_context import IconScoreContext, ContextGetter
+from iconservice.iconscore.icon_score_constant import FORMAT_IS_NOT_DERIVED_OF_OBJECT, ScoreFlag
 from iconservice.iconscore.icon_score_context_util import IconScoreContextUtil
 from iconservice.iconscore.icx import Icx
+from iconservice.iconscore.system import IconNetworkValueType
+from iconservice.iconscore.typing.element import get_score_flag
+from iconservice.utils import is_builtin_score, is_any_flag_on
 
-from .context import Context, score_mapper, interface_score_mapper
-from ..mock.db import MockKeyValueDatabase
+from .context import Context, score_mapper, interface_score_mapper, context_db, icon_network_value
 from ..mock.icx_engine import IcxEngine
 
-context_db = None
-
 
 def hooking_get_balance(address: 'Address'):
     """Hooking method for icx.get_balance"""
@@ -47,9 +47,9 @@ def hooking_get_balance(address: 'Address'):
 
 def hooking_transfer(_to: 'Address', amount: int):
     """Hooking method for icx.transfer"""
-    ctx = ContextGetter._context
+    ctx = Context.get_context()
     sender = ctx.msg.sender
-    IcxEngine.transfer(ContextGetter._context, sender, _to, amount)
+    IcxEngine.transfer(ctx, sender, _to, amount)
 
 
 def hooking_sha_256(data):
@@ -69,6 +69,21 @@ def start_SCORE_APIs_patch(score_module_path: str):
     patch(f"{score_module_path}.recover_key", side_effect=_recover_key).start()
 
 
+def hooking_migrate_icon_network_value(self, data: Dict['IconNetworkValueType', Any]):
+    for key, value in data.items():
+        icon_network_value[key] = value
+
+
+def hooking_get_icon_network_value(self, type_: 'IconNetworkValueType'):
+    self._check_inv_type(type_)
+    return icon_network_value.get(type_)
+
+
+def hooking_set_icon_network_value(self, type_: 'IconNetworkValueType', value: Any):
+    self._check_inv_type(type_)
+    icon_network_value[type_] = value
+
+
 def create_address(prefix: AddressPrefix = AddressPrefix.EOA) -> 'Address':
     return Address.from_bytes(prefix.to_bytes(1, 'big') + os.urandom(20))
 
@@ -87,20 +102,20 @@ def patch_score_method(method):
 
     @wraps(method)
     def patched(*args, **kwargs):
-        context: 'Mock' = ContextGetter._context
-        method_flag = getattr(method, CONST_BIT_FLAG, 0)
-        score_class, method_name = method.__qualname__.split('.')
+        context: 'Mock' = Context.get_context()
+        method_flag = get_score_flag(method)
+        _, method_name = method.__qualname__.split('.')
         context.current_address = method.__self__.address
 
         if method_name == 'fallback':
-            if not (method_flag & ConstBitFlag.Payable) and context.msg.value > 0:
+            if not (method_flag & ScoreFlag.PAYABLE) and context.msg.value > 0:
                 raise InvalidPayableException(f"This method is not payable")
 
-        if method_flag & ConstBitFlag.ReadOnly == ConstBitFlag.ReadOnly:
+        if method_flag & ScoreFlag.READONLY == ScoreFlag.READONLY:
             Context._set_query_context(context)
         else:
             Context._set_invoke_context(context)
-        if method_flag & ConstBitFlag.Payable:
+        if method_flag & ScoreFlag.PAYABLE:
             IcxEngine.transfer(context, context.msg.sender, context.current_address, context.msg.value)
 
         context.readonly = context.type == IconScoreContextType.QUERY or context.func_type == IconScoreFuncType.READONLY
@@ -140,7 +155,6 @@ class ScorePatcher:
         :param score_address: address of score.
         :return: db SCORE use
         """
-        global context_db
         if not score_address:
             score_address = create_address(AddressPrefix.CONTRACT)
         score_db = IconScoreDatabase(score_address, context_db)
@@ -155,8 +169,6 @@ class ScorePatcher:
         :param owner: owner of SCORE
         :return: Instantiated SCORE
         """
-        context = Context.get_context()
-        ScorePatcher._set_mock_context(context)
         Context.set_msg(owner, 0)
         score = score_class(score_db)
         ScorePatcher.patch_score_methods(score)
@@ -164,26 +176,10 @@ class ScorePatcher:
         ScorePatcher.patch_interface_scores(score)
         ScorePatcher.patch_deprecated_methods(score)
         score_mapper[score.address] = score
+        if is_builtin_score(str(score.address)):
+            ScorePatcher.patch_system_score(score)
         return score
 
-    @staticmethod
-    def _set_mock_context(context: 'IconScoreContext'):
-        mock_context = Mock(spec=IconScoreContext)
-        mock_context.configure_mock(msg=context.msg)
-        mock_context.configure_mock(tx=context.tx)
-        mock_context.configure_mock(block=context.block)
-        mock_context.configure_mock(step_counter=None)
-        mock_context.configure_mock(type=context.type)
-        mock_context.configure_mock(func_type=context.func_type)
-        mock_context.configure_mock(current_address=context.current_address)
-        mock_context.configure_mock(block_batch=context.block_batch)
-        mock_context.configure_mock(tx_batch=context.tx_batch)
-        mock_context.configure_mock(event_logs=context.event_logs)
-        mock_context.configure_mock(event_log_stack=context.event_log_stack)
-        mock_context.configure_mock(traces=context.traces)
-        mock_context.configure_mock(icon_score_mapper=context.icon_score_mapper)
-        ContextGetter._context = mock_context
-
     @staticmethod
     def patch_score_methods(score):
         """Patch all SCORE method by calling patch_score_method function
@@ -206,7 +202,9 @@ class ScorePatcher:
         custom_methods = ScorePatcher._get_custom_methods(score)
         methods = set()
         for method in custom_methods:
-            if getattr(method, CONST_BIT_FLAG, 0) in (0, 1, 2, 3, 4) or method.__name__ in ('on_install', 'on_update'):
+            flag = get_score_flag(method)
+            if is_any_flag_on(flag, ScoreFlag.FUNC | ScoreFlag.EVENTLOG) or \
+                    method.__name__ in ("on_install", "on_update"):
                 methods.add(method)
 
         methods.add(getattr(score, 'fallback'))
@@ -252,7 +250,8 @@ class ScorePatcher:
         """
         custom_methods = ScorePatcher._get_custom_methods(score.__class__)
         for method in custom_methods:
-            if getattr(method, CONST_BIT_FLAG, 0) == ConstBitFlag.EventLog:
+            flag = get_score_flag(method)
+            if flag == ScoreFlag.EVENTLOG:
                 setattr(score, method.__name__, Mock())
 
     @staticmethod
@@ -265,12 +264,8 @@ class ScorePatcher:
 
     @staticmethod
     def start_patches():
-        """Patch SCORE to use dictionary DB instance of LEVEL DB"""
-
-        global context_db
-        context_db = MockKeyValueDatabase.create_db()
-        IcxEngine.db = context_db
-        patch('iconservice.iconscore.icon_score_context.ContextGetter._context').start()
+        patch('iconservice.iconscore.context.context.ContextContainer._get_context',
+              side_effect=lambda: Context.get_context()).start()
         patch.object(Icx, "get_balance", side_effect=hooking_get_balance).start()
         patch.object(Icx, "transfer", side_effect=hooking_transfer).start()
         patch.object(IconScoreContextUtil, "get_owner",
@@ -278,8 +273,11 @@ class ScorePatcher:
 
     @staticmethod
     def stop_patches():
-        """Stop patching and clear db"""
         patch.stopall()
-        IcxEngine.db.close()
-        score_mapper.clear()
-        interface_score_mapper.clear()
+
+    @staticmethod
+    def patch_system_score(score):
+        score.get_icon_network_value = types.MethodType(hooking_get_icon_network_value, score)
+        score.set_icon_network_value = types.MethodType(hooking_set_icon_network_value, score)
+        score.migrate_icon_network_value = types.MethodType(hooking_migrate_icon_network_value, score)
+        score.disqualify_prep = types.MethodType(lambda self, address: (True, ""), score)
